@@ -5,19 +5,19 @@
 #include "simulator.h"
 #include "policy.h"
 
-/** 
+/**
  *  Base class.
  */
 class Activity {
 public:
   BASE_CLONEABLE(Activity)
-  
+
   std::string name;
   bool verbose;
   bool provide_attrs;
   int n;
   int priority;
-  
+
   /**
    * Constructor.
    * @param name          the name of the activity
@@ -28,9 +28,9 @@ public:
   Activity(std::string name, bool verbose, bool provide_attrs = 0, int priority = 0)
     : name(name), verbose(verbose), provide_attrs(provide_attrs), n(1),
       priority(priority), next(NULL), prev(NULL) {}
-  
+
   virtual ~Activity() {}
-  
+
   /**
    * Print the activity info.
    * @param indent number of spaces at the beginning of each line
@@ -40,41 +40,38 @@ public:
       for (int i = 0; i < indent; ++i)
         Rcpp::Rcout << " ";
       Rcpp::Rcout << "{ Activity: " << FMT(12, left) << name << " | ";
-      if (verbose) Rcpp::Rcout << 
+      if (verbose) Rcpp::Rcout <<
         FMT(9, right) << prev << " <- " <<
         FMT(9, right) << this << " -> " <<
         FMT(9, left) << next << " | ";
     }
   }
-  
+
   /**
    * Run the activity.
    * @param arrival a pointer to the calling arrival
    */
   virtual double run(Arrival* arrival) = 0;
-  
+
   /**
    * Getter/setter for the next activity in the chain.
    */
   virtual Activity* get_next() { return next; }
   virtual void set_next(Activity* activity) { next = activity; }
-  
+
   /**
    * Getter/setter for the previous activity in the chain.
    */
   virtual Activity* get_prev() { return prev; }
   virtual void set_prev(Activity* activity) { prev = activity; }
-  
+
 protected:
   Activity* next;
   Activity* prev;
-  
+
   template <typename T>
   T get(T var, Arrival* arrival) { return var; }
-  
-  template <typename T>
-  T get(VEC<T> var, Arrival* arrival) { return var[0]; }
-  
+
   template <typename T>
   T get(Rcpp::Function call, Arrival* arrival) {
     if (provide_attrs)
@@ -86,9 +83,9 @@ protected:
 // abstract class for multipath activities
 class Fork : public Activity {
 public:
-  Fork(std::string name, bool verbose, VEC<bool> cont, VEC<Rcpp::Environment> trj, 
+  Fork(std::string name, bool verbose, VEC<bool> cont, VEC<Rcpp::Environment> trj,
        bool provide_attrs = 0, int priority = 0)
-    : Activity(name, verbose, provide_attrs, priority), 
+    : Activity(name, verbose, provide_attrs, priority),
       cont(cont), trj(trj), selected(NULL)
   {
     foreach_ (VEC<Rcpp::Environment>::value_type& itr, trj) {
@@ -102,9 +99,9 @@ public:
     foreach_ (VEC<Activity*>::value_type& itr, heads)
       itr->set_prev(this);
   }
-  
+
   Fork(const Fork& o)
-    : Activity(o.name, o.verbose, o.provide_attrs, o.priority), 
+    : Activity(o.name, o.verbose, o.provide_attrs, o.priority),
       cont(o.cont), trj(o.trj), selected(NULL)
   {
     heads.clear();
@@ -120,7 +117,7 @@ public:
     foreach_ (VEC<Activity*>::value_type& itr, heads)
       itr->set_prev(this);
   }
-  
+
   void print(int indent = 0, bool brief = false) {
     indent += 2;
     if (!brief)
@@ -132,14 +129,14 @@ public:
       }
     else Rcpp::Rcout << trj.size() << " paths" << std::endl;
   }
-  
+
   void set_next(Activity* activity) {
     Activity::set_next(activity);
     for (unsigned int i = 0; i < tails.size(); i++) {
       if (cont[i]) tails[i]->set_next(activity);
     }
   }
-  
+
   Activity* get_next() {
     if (selected) {
       Activity* aux = selected;
@@ -148,7 +145,7 @@ public:
     }
     return Activity::get_next();
   }
-  
+
 protected:
   VEC<bool> cont;
   VEC<Rcpp::Environment> trj;
@@ -164,34 +161,34 @@ template <typename T>
 class Seize : public Fork {
 public:
   CLONEABLE(Seize<T>)
-  
-  Seize(bool verbose, std::string resource, T amount, bool provide_attrs, 
+
+  Seize(bool verbose, std::string resource, T amount, bool provide_attrs,
         VEC<bool> cont, VEC<Rcpp::Environment> trj, unsigned short mask)
-    : Fork("Seize", verbose, cont, trj, provide_attrs), 
+    : Fork("Seize", verbose, cont, trj, provide_attrs),
       resource(resource), amount(amount), mask(mask) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "resource: " << resource << " | " << "amount: " << amount << " }" << std::endl;
     else Rcpp::Rcout << resource << ", " << amount << ", ";
     Fork::print(indent, brief);
   }
-  
+
   double run(Arrival* arrival) {
     int value = std::abs(get<int>(amount, arrival));
     return select_path(arrival, get_resource(arrival)->seize(arrival, value));
   }
-  
+
 protected:
   std::string resource;
   T amount;
   unsigned short mask;
-  
+
   virtual Resource* get_resource(Arrival* arrival) {
     return arrival->sim->get_resource(resource);
   }
-  
+
   int select_path(Arrival* arrival, int ret) {
     switch (ret) {
     case REJECTED:
@@ -219,14 +216,14 @@ template <typename T>
 class SeizeSelected : public Seize<T> {
 public:
   CLONEABLE(SeizeSelected<T>)
-  
-  SeizeSelected(bool verbose, int id, T amount, bool provide_attrs, 
+
+  SeizeSelected(bool verbose, int id, T amount, bool provide_attrs,
                 VEC<bool> cont, VEC<Rcpp::Environment> trj, unsigned short mask)
     : Seize<T>(verbose, "[]", amount, provide_attrs, cont, trj, mask), id(id) {}
-  
+
 protected:
   int id;
-  
+
   Resource* get_resource(Arrival* arrival) {
     return arrival->get_selected(id);
   }
@@ -239,27 +236,27 @@ template <typename T>
 class Release : public Activity {
 public:
   CLONEABLE(Release<T>)
-  
+
   Release(bool verbose, std::string resource, T amount, bool provide_attrs)
-    : Activity("Release", verbose, provide_attrs, PRIORITY_RELEASE), 
+    : Activity("Release", verbose, provide_attrs, PRIORITY_RELEASE),
       resource(resource), amount(amount) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "resource: " << resource << " | " << "amount: " << amount << " }" << std::endl;
     else Rcpp::Rcout << resource << ", " << amount << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     int value = std::abs(get<int>(amount, arrival));
     return get_resource(arrival)->release(arrival, value);
   }
-  
+
 protected:
   std::string resource;
   T amount;
-  
+
   virtual Resource* get_resource(Arrival* arrival) {
     return arrival->sim->get_resource(resource);
   }
@@ -272,13 +269,13 @@ template <typename T>
 class ReleaseSelected : public Release<T> {
 public:
   CLONEABLE(ReleaseSelected<T>)
-  
+
   ReleaseSelected(bool verbose, int id, T amount, bool provide_attrs)
     : Release<T>(verbose, "[]", amount, provide_attrs), id(id) {}
-  
+
 protected:
   int id;
-  
+
   Resource* get_resource(Arrival* arrival) {
     return arrival->get_selected(id);
   }
@@ -291,23 +288,23 @@ template <typename T>
 class Select : public Activity {
 public:
   CLONEABLE(Select<T>)
-  
+
   Select(bool verbose, T resources, bool provide_attrs, std::string policy, int id)
     : Activity("Select", verbose, provide_attrs), resources(resources),
       policy(policy), id(id), dispatcher(Policy(resources, policy)) {}
-  
+
   void print(int indent = 0, bool brief = false);
-  
+
   double run(Arrival* arrival) {
     Resource* selected;
     if (typeid(T) == typeid(Rcpp::Function)) {
-      std::string res = get<std::string>(resources, arrival);
-      selected = arrival->sim->get_resource(res);
+      VEC<std::string> res = get<VEC<std::string> >(resources, arrival);
+      selected = arrival->sim->get_resource(res[0]);
     } else selected = dispatcher.dispatch(arrival->sim);
     arrival->set_selected(id, selected);
     return 0;
   }
-  
+
 protected:
   T resources;
   std::string policy;
@@ -322,22 +319,22 @@ template <typename T>
 class SetAttribute : public Activity {
 public:
   CLONEABLE(SetAttribute<T>)
-  
+
   SetAttribute(bool verbose, std::string key, T value, bool provide_attrs)
     : Activity("SetAttribute", verbose, provide_attrs), key(key), value(value) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "key: " << key << ", value: " << value << " }" << std::endl;
     else Rcpp::Rcout << key << ": " << value << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     double ret = get<double>(value, arrival);
     return arrival->set_attribute(key, ret);
   }
-  
+
 protected:
   std::string key;
   T value;
@@ -350,22 +347,22 @@ template <typename T>
 class SetPrior : public Activity {
 public:
   CLONEABLE(SetPrior<T>)
-  
+
   SetPrior(bool verbose, T values, bool provide_attrs)
     : Activity("SetPrior", verbose, provide_attrs), values(values) {}
-  
+
   void print(int indent = 0, bool brief = false);
-  
+
   double run(Arrival* arrival) {
     VEC<int> ret = get<VEC<int> >(values, arrival);
-    if (ret.size() != 3) 
+    if (ret.size() != 3)
       Rcpp::stop("%s: 3 values needed", name);
     if (ret[0] >= 0) arrival->order.set_priority(ret[0]);
     if (ret[1] >= 0) arrival->order.set_preemptible(ret[1]);
     if (ret[2] >= 0) arrival->order.set_restart((bool)ret[2]);
     return 0;
   }
-  
+
 protected:
   T values;
 };
@@ -377,21 +374,21 @@ template <typename T>
 class Timeout : public Activity {
 public:
   CLONEABLE(Timeout<T>)
-  
+
   Timeout(bool verbose, T delay, bool provide_attrs)
     : Activity("Timeout", verbose, provide_attrs), delay(delay) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
     if (!brief) Rcpp::Rcout << "delay: " << delay << " }" << std::endl;
     else Rcpp::Rcout << delay << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     double value = get<double>(delay, arrival);
     return std::abs(value);
   }
-  
+
 protected:
   T delay;
 };
@@ -403,19 +400,19 @@ protected:
 class Branch : public Fork {
 public:
   CLONEABLE(Branch)
-  
-  Branch(bool verbose, Rcpp::Function option, bool provide_attrs, 
+
+  Branch(bool verbose, Rcpp::Function option, bool provide_attrs,
          VEC<bool> cont, VEC<Rcpp::Environment> trj)
     : Fork("Branch", verbose, cont, trj, provide_attrs), option(option) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "option: " << option << " }" << std::endl;
     else Rcpp::Rcout << option << ", ";
     Fork::print(indent, brief);
   }
-  
+
   double run(Arrival* arrival) {
     int ret = get<int>(option, arrival);
     if (ret < 0 || ret > (int)heads.size())
@@ -423,7 +420,7 @@ public:
     if (ret) selected = heads[ret-1];
     return 0;
   }
-  
+
 protected:
   Rcpp::Function option;
 };
@@ -434,19 +431,19 @@ protected:
 class Rollback : public Activity {
 public:
   CLONEABLE(Rollback)
-  
-  Rollback(bool verbose, int amount, int times, 
+
+  Rollback(bool verbose, int amount, int times,
            OPT<Rcpp::Function> check = NONE, bool provide_attrs = false)
     : Activity("Rollback", verbose, provide_attrs), amount(std::abs(amount)),
       times(times), check(check), cached(NULL), selected(NULL) {}
-  
+
   Rollback(const Rollback& o)
-    : Activity(o.name, o.verbose, o.provide_attrs), amount(o.amount), 
+    : Activity(o.name, o.verbose, o.provide_attrs), amount(o.amount),
       times(o.times), check(o.check), cached(NULL), selected(NULL)
   {
     pending.clear();
   }
-  
+
   void print(int indent = 0, bool brief = false) {
     if (!cached) cached = goback();
     Activity::print(indent, brief);
@@ -460,13 +457,13 @@ public:
       Rcpp::Rcout << " }" << std::endl;
     } else Rcpp::Rcout << cached->name << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     if (check) {
       if (!get<bool>(*check, arrival))
         return 0;
     } else if (times >= 0) {
-      if (pending.find(arrival) == pending.end()) 
+      if (pending.find(arrival) == pending.end())
         pending[arrival] = times;
       if (!pending[arrival]) {
         pending.erase(arrival);
@@ -478,7 +475,7 @@ public:
     selected = cached;
     return 0;
   }
-  
+
   Activity* get_next() {
     if (selected) {
       Activity* aux = selected;
@@ -487,14 +484,14 @@ public:
     }
     return Activity::get_next();
   }
-  
+
 protected:
   int amount;
   int times;
   OPT<Rcpp::Function> check;
   Activity* cached, *selected;
   UMAP<Arrival*, int> pending;
-  
+
   Activity* goback() {
     int n = amount;
     Activity* ptr = this;
@@ -511,24 +508,24 @@ template <typename T>
 class Leave : public Activity {
 public:
   CLONEABLE(Leave<T>)
-  
+
   Leave(bool verbose, T prob, bool provide_attrs)
     : Activity("Leave", verbose, provide_attrs), prob(prob) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "prob: " << prob << " }" << std::endl;
     else Rcpp::Rcout << prob << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     if (Rcpp::runif(1)[0] > get<double>(prob, arrival))
       return 0;
     arrival->terminate(false);
     return REJECTED;
   }
-  
+
 protected:
   T prob;
 };
@@ -540,19 +537,19 @@ template <typename T>
 class Clone : public Fork {
 public:
   CLONEABLE(Clone<T>)
-  
+
   Clone(bool verbose, T n, bool provide_attrs, VEC<Rcpp::Environment> trj)
-    : Fork("Clone", verbose, VEC<bool>(trj.size(), true), trj, provide_attrs), 
+    : Fork("Clone", verbose, VEC<bool>(trj.size(), true), trj, provide_attrs),
       n(n) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "n: " << n << " }" << std::endl;
     else Rcpp::Rcout << n << ", ";
     Fork::print(indent, brief);
   }
-  
+
   double run(Arrival* arrival) {
     int value = std::abs(get<int>(n, arrival));
     for (int i = 1; i < value; i++) {
@@ -566,7 +563,7 @@ public:
       selected = heads[0];
     return 0;
   }
-  
+
 protected:
   T n;
 };
@@ -577,23 +574,23 @@ protected:
 class Synchronize : public Activity {
 public:
   CLONEABLE(Synchronize)
-  
+
   Synchronize(bool verbose, bool wait, bool terminate)
     : Activity("Synchronize", verbose), wait(wait), terminate(terminate) {}
-  
+
   Synchronize(const Synchronize& o)
     : Activity(o.name, o.verbose), wait(o.wait), terminate(o.terminate)
   {
     pending.clear();
   }
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "wait: " << wait << " }" << std::endl;
     else Rcpp::Rcout << wait << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     if (!wait) {
       UMAP<std::string, int>::iterator search = pending.find(arrival->name);
@@ -608,14 +605,14 @@ public:
       }
     } else if (*(arrival->clones) == 1)
       return 0;
-    
-    if (!terminate) 
+
+    if (!terminate)
       delete arrival;
-    else 
+    else
       arrival->terminate(true);
     return REJECTED;
   }
-  
+
 protected:
   bool wait;
   bool terminate;
@@ -628,20 +625,20 @@ protected:
 class Batch : public Activity {
 public:
   CLONEABLE(Batch)
-  
+
   Batch(bool verbose, int n, double timeout, bool permanent, std::string id = "",
         OPT<Rcpp::Function> rule = NONE, bool provide_attrs = false)
-    : Activity("Batch", verbose, provide_attrs), n(n), 
+    : Activity("Batch", verbose, provide_attrs), n(n),
       timeout(std::abs(timeout)), permanent(permanent), id(id), rule(rule) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
-      "n: " << n << ", timeout: " << timeout << ", permanent: " << permanent << 
+    if (!brief) Rcpp::Rcout <<
+      "n: " << n << ", timeout: " << timeout << ", permanent: " << permanent <<
       ", name: " << id << " }" << std::endl;
     else Rcpp::Rcout << n << ", " << timeout << ", " << permanent << ", " << id << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     if (rule && !get<bool>(*rule, arrival))
       return 0;
@@ -650,10 +647,10 @@ public:
       *ptr = init(arrival->sim);
     (*ptr)->insert(arrival);
     if ((int)(*ptr)->size() == n)
-      trigger(*ptr);
+      trigger(arrival->sim, *ptr);
     return REJECTED;
   }
-  
+
 protected:
   int n;
   double timeout;
@@ -669,14 +666,14 @@ protected:
       str= "batch" + boost::lexical_cast<std::string>(sim->get_batch_count());
     Batched* ptr = new Batched(sim, str, permanent);
     if (timeout) {
-      Task* task = new Task(sim, "Batch-Timer", boost::bind(&Batch::trigger, this, ptr));
+      Task* task = new Task(sim, "Batch-Timer", boost::bind(&Batch::trigger, this, sim, ptr));
       sim->schedule(timeout, task, PRIORITY_MIN);
     }
     return ptr;
   }
-  
-  void trigger(Batched* target) {
-    Batched** ptr = target->sim->get_batch(this, id);
+
+  void trigger(Simulator* sim, Batched* target) {
+    Batched** ptr = sim->get_batch(this, id);
     if (!(*ptr) || *ptr != target)
       return;
     if ((*ptr)->size()) {
@@ -696,15 +693,15 @@ protected:
 class Separate : public Activity {
 public:
   CLONEABLE(Separate)
-  
+
   Separate(bool verbose) : Activity("Separate", verbose) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
     if (!brief) Rcpp::Rcout << " }" << std::endl;
     else Rcpp::Rcout << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     Batched* batched = dynamic_cast<Batched*>(arrival);
     if (!batched || batched->is_permanent())
@@ -722,19 +719,19 @@ template <typename T>
 class RenegeIn : public Fork {
 public:
   CLONEABLE(RenegeIn<T>)
-  
+
   RenegeIn(bool verbose, T t, bool provide_attrs, VEC<Rcpp::Environment> trj)
-    : Fork("RenegeIn", verbose, VEC<bool>(trj.size(), false), trj, provide_attrs), 
+    : Fork("RenegeIn", verbose, VEC<bool>(trj.size(), false), trj, provide_attrs),
       t(t) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
-    if (!brief) Rcpp::Rcout << 
+    if (!brief) Rcpp::Rcout <<
       "t: " << t << " }" << std::endl;
     else Rcpp::Rcout << t << ", ";
     Fork::print(indent, brief);
   }
-  
+
   double run(Arrival* arrival) {
     double ret = std::abs(get<double>(t, arrival));
     Activity* next = NULL;
@@ -743,7 +740,7 @@ public:
     arrival->set_timeout(ret, next);
     return 0;
   }
-  
+
 protected:
   T t;
 };
@@ -754,15 +751,15 @@ protected:
 class RenegeAbort : public Activity {
 public:
   CLONEABLE(RenegeAbort)
-  
+
   RenegeAbort(bool verbose) : Activity("RenegeAbort", verbose) {}
-  
+
   void print(int indent = 0, bool brief = false) {
     Activity::print(indent, brief);
     if (!brief) Rcpp::Rcout << " }" << std::endl;
     else Rcpp::Rcout << std::endl;
   }
-  
+
   double run(Arrival* arrival) {
     arrival->cancel_timeout();
     return 0;
