@@ -9,22 +9,22 @@ void Generator::run() {
   Rcpp::NumericVector delays = dist();
   int n = delays.size();
   double delay = 0;
-  
+
   for(int i = 0; i < n; ++i) {
     if (delays[i] < 0)
       return;
     delay += delays[i];
-    
+
     // format the name and create the next arrival
     std::string arr_name = name + boost::lexical_cast<std::string>(count++);
     Arrival* arrival = new Arrival(sim, arr_name, is_monitored(), order, first_activity);
-    
-    if (sim->verbose)Rcpp::Rcout << 
-      FMT(10, right) << sim->now() << " |" << 
-      FMT(12, right) << "generator: " << FMT(15, left) << name << "|" << 
-      FMT(12, right) << "new: " << FMT(15, left) << arr_name << "| " << 
+
+    if (sim->verbose)Rcpp::Rcout <<
+      FMT(10, right) << sim->now() << " |" <<
+      FMT(12, right) << "generator: " << FMT(15, left) << name << "|" <<
+      FMT(12, right) << "new: " << FMT(15, left) << arr_name << "| " <<
       (sim->now() + delay) << std::endl;
-    
+
     // schedule the arrival
     sim->register_arrival(arrival);
     sim->schedule(delay, arrival, count);
@@ -37,11 +37,11 @@ void Manager::run() {
   if (!sim->now() && duration[index])
     goto finish;
   if (sim->verbose) Rcpp::Rcout <<
-    FMT(10, right) << sim->now() << " |" << 
-    FMT(12, right) << "manager: " << FMT(15, left) << name << "|" << 
-    FMT(12, right) << "parameter: " << FMT(15, left) << param << "| " << 
+    FMT(10, right) << sim->now() << " |" <<
+    FMT(12, right) << "manager: " << FMT(15, left) << name << "|" <<
+    FMT(12, right) << "parameter: " << FMT(15, left) << param << "| " <<
     value[index] << std::endl;
-  
+
   set(value[index]);
   index++;
   if (index == duration.size()) {
@@ -49,7 +49,7 @@ void Manager::run() {
       goto end;
     index = 1;
   }
-  
+
 finish:
   sim->schedule(duration[index], this, PRIORITY_MANAGER);
 end:
@@ -58,16 +58,18 @@ end:
 
 void Task::run() {
   if (sim->verbose) Rcpp::Rcout <<
-    FMT(10, right) << sim->now() << " |" << 
-    FMT(12, right) << "task: " << FMT(15, left) << name << "|" << 
+    FMT(10, right) << sim->now() << " |" <<
+    FMT(12, right) << "task: " << FMT(15, left) << name << "|" <<
     FMT(12, right) << " " << FMT(15, left) << " " << "| " << std::endl;
-  
+
   task();
   delete this;
 }
 
 void Arrival::reset() {
   cancel_timeout();
+  foreach_ (ResMSet::value_type& itr, resources)
+    Rcpp::warning("`%s`: leaving without releasing `%s`", name, itr->name);
   if (!--(*clones))
     delete clones;
   sim->unregister_arrival(this);
@@ -75,32 +77,32 @@ void Arrival::reset() {
 
 void Arrival::run() {
   double delay;
-  
+
   if (!activity)
     goto finish;
   if (lifetime.start < 0)
     lifetime.start = sim->now();
-  
+
   if (sim->verbose) {
     Rcpp::Rcout <<
-      FMT(10, right) << sim->now() << " |" << 
-      FMT(12, right) << "arrival: " << FMT(15, left) << name << "|" << 
+      FMT(10, right) << sim->now() << " |" <<
+      FMT(12, right) << "arrival: " << FMT(15, left) << name << "|" <<
       FMT(12, right) << "activity: " << FMT(15, left) << activity->name << "| ";
     activity->print(0, true);
   }
-  
+
   delay = activity->run(this);
   if (delay == REJECTED)
     goto end;
   activity = activity->get_next();
   if (delay == ENQUEUED)
     goto end;
-  
+
   lifetime.busy_until = sim->now() + delay;
   lifetime.activity += delay;
   sim->schedule(delay, this, activity ? activity->priority : 0);
   goto end;
-  
+
 finish:
   terminate(true);
 end:
@@ -163,7 +165,7 @@ void Arrival::renege(Activity* next) {
 
 int Arrival::set_attribute(std::string key, double value) {
   attributes[key] = value;
-  if (is_monitored() >= 2) 
+  if (is_monitored() >= 2)
     sim->record_attribute(name, key, value);
   return 0;
 }
@@ -212,7 +214,7 @@ int Batched::set_attribute(std::string key, double value) {
 }
 
 void Batched::erase(Arrival* arrival) {
-  bool del = true;
+  bool del = activity;
   if (arrivals.size() > 1 || (batch && batch->is_permanent())) {
     del = false;
     if (arrival->is_monitored()) {
@@ -223,7 +225,7 @@ void Batched::erase(Arrival* arrival) {
       }
     }
   } else if (arrivals.size() == 1 && !batch) {
-    bool ret = false;
+    bool ret = !activity;
     while (resources.begin() != resources.end())
       ret |= (*resources.begin())->erase(this);
     if (!ret)
